@@ -25,7 +25,7 @@ def uninstall(version=None, packages=None):
     ----------
     version : {'5.0', '6.0', '7.0', '8.0'}, optional
         The version number of Rhino.
-        Default is ``'6.0'``.
+        Default is ``'7.0'``.
     packages : list of str, optional
         List of packages to uninstall.
         Default is to uninstall all packages installed by the COMPAS installer.
@@ -35,23 +35,25 @@ def uninstall(version=None, packages=None):
     .. code-block:: python
 
         import compas_rhino
-        compas_rhino.uninstall('6.0')
+        compas_rhino.uninstall()
 
     .. code-block:: bash
 
-        python -m compas_rhino.uninstall -v 6.0
+        python -m compas_rhino.uninstall
 
     """
-    if version not in ('5.0', '6.0', '7.0', '8.0'):
-        version = '6.0'
+    version = compas_rhino._check_rhino_version(version)
 
     # We install COMPAS packages in the scripts folder
     # instead of directly as IPy module.
-    scripts_path = compas_rhino._get_scripts_path(version)
+    scripts_path = compas_rhino._get_rhino_scripts_path(version)
 
     # This is for old installs
-    ipylib_path = compas_rhino._get_ironpython_lib_path(version)
+    ipylib_path = compas_rhino._get_rhino_ironpython_lib_path(version)
 
+    # Filter the provided list of packages
+    # If no packages are provided
+    # this first collects all installable packages from the environment.
     packages = _filter_installed_packages(version, packages)
 
     # Also remove all broken symlinks
@@ -63,11 +65,8 @@ def uninstall(version=None, packages=None):
                 if name not in packages:
                     packages.append(name)
 
-    print('Uninstalling COMPAS packages from Rhino {0} scripts folder: \n{1}'.format(version, scripts_path))
-
-    results = []
+    # Collect paths for removal based on package names
     symlinks_to_uninstall = []
-    exit_code = 0
 
     for package in packages:
         symlink_path = os.path.join(scripts_path, package)
@@ -81,55 +80,67 @@ def uninstall(version=None, packages=None):
             if os.path.exists(legacy_path):
                 symlinks_to_uninstall.append(dict(name=package, link=legacy_path))
 
+    # There is nothing to uninstall
     if not symlinks_to_uninstall:
-        print('\nNo packages to uninstall.')
+        print('\nNo packages to uninstall from Rhino {0} scripts folder: \n{1}.'.format(version, scripts_path))
+        return
+
+    # -------------------------
+    # Start uninstalling
+    # -------------------------
+
+    uninstalled_packages = []
+    results = []
+    exit_code = 0
+
+    symlinks = [link['link'] for link in symlinks_to_uninstall]
+    uninstall_results = compas._os.remove_symlinks(symlinks)
+
+    for uninstall_data, success in zip(symlinks_to_uninstall, uninstall_results):
+        if success:
+            uninstalled_packages.append(uninstall_data['name'])
+            result = 'OK'
+        else:
+            result = 'ERROR: Cannot remove symlink, try to run as administrator.'
+
+        results.append((uninstall_data['name'], result))
+
+    if not all(uninstall_results):
+        exit_code = -1
+
+    if exit_code == -1:
+        results.append(('compas_bootstrapper', 'WARNING: One or more packages failed, will not uninstall bootstrapper.'))
 
     else:
-        uninstalled_packages = []
+        if compas_rhino._try_remove_bootstrapper(scripts_path):
+            results.append(('compas_bootstrapper', 'OK'))
+        else:
+            results.append(('compas_bootstrapper', 'ERROR: Cannot remove compas_bootstrapper, try to run as administrator.'))
 
-        symlinks = [link['link'] for link in symlinks_to_uninstall]
-        uninstall_results = compas._os.remove_symlinks(symlinks)
+        # Handle legacy bootstrapper
+        # Again, only if possible...
+        if ipylib_path:
+            if not compas_rhino._try_remove_bootstrapper(ipylib_path):
+                results.append(('compas_bootstrapper', 'ERROR: Cannot remove legacy compas_bootstrapper, try to run as administrator.'))
 
-        for uninstall_data, success in zip(symlinks_to_uninstall, uninstall_results):
-            if success:
-                uninstalled_packages.append(uninstall_data['name'])
-                result = 'OK'
-            else:
-                result = 'ERROR: Cannot remove symlink, try to run as administrator.'
+    # -------------------------
+    # Output results
+    # -------------------------
 
-            results.append((uninstall_data['name'], result))
+    print('Uninstalling COMPAS packages from Rhino {0} scripts folder: \n{1}'.format(version, scripts_path))
+    print('\nThe following packages have been detected and will be uninstalled:\n')
 
-        if not all(uninstall_results):
+    for package, status in results:
+        print('   {} {}'.format(package.ljust(20), status))
+
+        if status != 'OK':
             exit_code = -1
 
-        if exit_code == -1:
-            results.append(('compas_bootstrapper', 'WARNING: One or more packages failed, will not uninstall bootstrapper.'))
+    if exit_code == 0 and uninstalled_packages:
+        print('\nRunning post-uninstallation steps...\n')
 
-        else:
-            if compas_rhino._try_remove_bootstrapper(scripts_path):
-                results.append(('compas_bootstrapper', 'OK'))
-            else:
-                results.append(('compas_bootstrapper', 'ERROR: Cannot remove compas_bootstrapper, try to run as administrator.'))
-
-            # Handle legacy bootstrapper
-            # Again, only if possible...
-            if ipylib_path:
-                if not compas_rhino._try_remove_bootstrapper(ipylib_path):
-                    results.append(('compas_bootstrapper', 'ERROR: Cannot remove legacy compas_bootstrapper, try to run as administrator.'))
-
-        print('\nThe following packages have been detected and will be uninstalled:\n')
-
-        for package, status in results:
-            print('   {} {}'.format(package.ljust(20), status))
-
-            if status != 'OK':
-                exit_code = -1
-
-        if exit_code == 0 and uninstalled_packages:
-            print('\nRunning post-uninstallation steps...\n')
-
-            if not _run_post_execution_steps(after_rhino_uninstall(uninstalled_packages)):
-                exit_code = -1
+        if not _run_post_execution_steps(after_rhino_uninstall(uninstalled_packages)):
+            exit_code = -1
 
     print('\nUninstall completed.')
 
@@ -138,8 +149,8 @@ def uninstall(version=None, packages=None):
 
 
 def _filter_installed_packages(version, packages):
-    ipylib_path = compas_rhino._get_ironpython_lib_path(version)
-    scripts_path = compas_rhino._get_scripts_path(version)
+    ipylib_path = compas_rhino._get_rhino_ironpython_lib_path(version)
+    scripts_path = compas_rhino._get_rhino_scripts_path(version)
 
     compas_bootstrapper = compas_rhino._get_bootstrapper_path(scripts_path)
     bootstrapper_data = compas_rhino._get_bootstrapper_data(compas_bootstrapper)
@@ -207,7 +218,13 @@ if __name__ == "__main__":
 
     parser = argparse.ArgumentParser()
 
-    parser.add_argument('-v', '--version', choices=['5.0', '6.0', '7.0', '8.0'], default='6.0', help="The version of Rhino to install the packages in.")
+    parser.add_argument(
+        '-v',
+        '--version',
+        choices=compas_rhino.SUPPORTED_VERSIONS,
+        default=compas_rhino.DEFAULT_VERSION,
+        help="The version of Rhino to install the packages in."
+    )
     parser.add_argument('-p', '--packages', nargs='+', help="The packages to uninstall.")
 
     args = parser.parse_args()
